@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11436 2019-04-10 17:56:15Z Lavender $
+# $Id: setup.py 11461 2019-04-16 18:26:42Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-11 02:56:15 +0900 (週四, 11 四月 2019) $
-# $Revision: 11436 $
+# $Date: 2019-04-17 03:26:42 +0900 (週三, 17 四月 2019) $
+# $Revision: 11461 $
 
 import os
 import sys
@@ -22,6 +22,7 @@ import logging
 import shutil
 import json
 import argparse
+import locale
 import traceback
 
 try:
@@ -311,7 +312,9 @@ if __name__ == "__main__":
         wizard = args.wizard
         mode = 'user'
         
-        timeLocal = time.strftime("%z", time.gmtime())
+        local = locale.getdefaultlocale()
+        if len(local) == 2 and local[0]:
+            local = local[0]
         
         if os.path.isfile(os.path.join(SETUP_DIR, 'MANIFAST.INFO')):
             with open(os.path.join(SETUP_DIR, 'MANIFAST.INFO')) as f:
@@ -328,7 +331,7 @@ if __name__ == "__main__":
         elif cmsVersion.startswith("3.6"):
             installVersion = "1.1.0"
         else:
-            installVersion = "1.0.0"
+            installVersion = "1.1.0"
            
         path = args.path
        
@@ -369,7 +372,7 @@ if __name__ == "__main__":
                 command = "djangocms -f -p \"%s\" \"%s\"" % (
                     path, projectName)
                     
-            if timeLocal in ["+0800",]:
+            if local and local in ["zh_TW", "zh_Hant"]:
                 command = "%s --languages=zh-hant" % command
                 
             result = os.system(command)
