@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11055 2018-05-14 09:46:32Z Lavender $
+# $Id: models.py 11178 2018-07-22 12:34:44Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,12 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-14 17:46:32 +0800 (週一, 14 五月 2018) $
-# $Revision: 11055 $
+# $Date: 2018-07-22 21:34:44 +0900 (週日, 22 七月 2018) $
+# $Revision: 11178 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
-from django.core.validators import MaxValueValidator
+from django.core.validators import MaxValueValidator, MinValueValidator
 
 from cms.models import CMSPlugin
 
@@ -103,4 +103,42 @@ class ShareLike(CMSPlugin):
     appId = models.CharField(_("Facebook API app ID"), max_length=20)
 
     width = models.PositiveIntegerField(_("Width"), default=450)
-    height = models.PositiveIntegerField(_("Height"), default=80)
\ No newline at end of file
+    height = models.PositiveIntegerField(_("Height"), default=80)
+
+TAB_CHOICE = (
+    ('timeline',  _("Timeline")),
+    ('events',  _("Events")),
+    ('messages',  _("Messages")),
+)
+
+class FanPage(CMSPlugin):
+    url = models.URLField()
+    appId = models.CharField(_("Facebook API app ID"), max_length=20)
+
+    width = models.PositiveIntegerField(
+        _("Width"), 
+        default=340,
+        validators=[
+            MaxValueValidator(500),
+            MinValueValidator(180)
+        ])
+    height = models.PositiveIntegerField(
+        _("Height"), 
+        default=500,
+        validators=[
+            MinValueValidator(70),
+        ])
+
+    tab = models.CharField(
+        _("Tab"),
+        max_length=10,
+        choices=TAB_CHOICE,
+        default='timeline',
+    )
+
+    hideCover = models.BooleanField(_("Hide cover"), default=False)
+    showFacepile = models.BooleanField(_("Show facepile"), default=True)
+    hideCta = models.BooleanField(_("Hide cta"), default=False)
+    smallHeader = models.BooleanField(_("Small header"), default=False)
+    adaptContainerWidth = models.BooleanField(
+        _("Adapt Container width"), default=False)
\ No newline at end of file
